Further Reading
===============

- `A Flexible FPGA-based Control Platform for Superconducting Multi-Qubit Experiments <https://publikationen.bibliothek.kit.edu/1000141695>`_
    PhD Thesis from Richard Gebauer, the original creator of the QiController
- `QiCells: A Modular RFSoC-based Approach to Interface Superconducting Quantum Bits <https://publikationen.bibliothek.kit.edu/1000155498>`_
    Paper about the general architecture
- `State preparation of a fluxonium qubit with feedback from a custom FPGA-based platform <https://arxiv.org/abs/1912.06814>`_
    Experimental Application of the QiController
- `Versatile Configuration and Control Framework for Real Time Data Acquisition Systems <https://arxiv.org/abs/1912.06814>`_
    Paper about the underlying Software Framework
- `A Modular RFSoC-based Approach to Interface Superconducting Quantum Bits <https://ieeexplore.ieee.org/document/9609909>`_
    Early paper about the QiController
- Tutorial about QiCode:
    :download:`Download <assets/QiCode_Tutorial.pdf>`
